﻿using System;
using System.Windows.Forms;

/* Homebrew Channel meta.xml editor - v1 source - WB3000
 * 
 * Example meta.xml...
 * 
 * <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
    <app version="1">
        <name>ScummVM</name>
        <coder>dhewg</coder>
        <version>rev32231</version>
        <release_date>200805230000</release_date>
        <short_description>Point &amp; Click Adventures</short_description>
        <long_description>ScummVM is a program which allows you to run certain classic graphical point-and-click adventure games, provided you already have their data files. The clever part about this: ScummVM just replaces the executables shipped with the games, allowing you to play them on systems for which they were never designed!</long_description>
    </app>
*/

namespace HBCMetaXML_Editor
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void button2_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            OpenFileDialog openmetaxml = new OpenFileDialog();
            if (openmetaxml.ShowDialog() == DialogResult.OK)
            { 
                string xmlfile = System.IO.File.ReadAllText(openmetaxml.FileName.ToString());
                xmlfilebox.Text = openmetaxml.FileName.ToString();
                appversion.Text = ReadValuefromXML(xmlfile, "<app version=", ">");
                appversion.Text = appversion.Text.Substring(1, appversion.Text.Length - 2);
                appname.Text = ReadValuefromXML(xmlfile, "<name>", "</name>");
                coder.Text = ReadValuefromXML(xmlfile, "<coder>", "</coder>");
                version.Text = ReadValuefromXML(xmlfile, "<version>", "</version>");
                releasedate.Text = ReadValuefromXML(xmlfile, "<release_date>", "</release_date>");
                shdesc.Text = ReadValuefromXML(xmlfile, "<short_description>", "</short_description>");
                lngdesc.Text = ReadValuefromXML(xmlfile, "<long_description>", "</long_description>");
            }
        }

        public string ReadValuefromXML(string xmlfile, string start, string end)
        {
            int startindex = xmlfile.IndexOf(start);
            int endindex = xmlfile.IndexOf(end, startindex);
            int length = endindex - (startindex + start.Length);
            return xmlfile.Substring(startindex + start.Length, length);
        }

        private void button3_Click(object sender, EventArgs e)
        {
            SaveFileDialog savemetaxml = new SaveFileDialog();
            savemetaxml.Filter = "XML Files|*.xml";
            savemetaxml.FileName = "meta.xml";
            if (CheckEverything() == true)
            {
                if (savemetaxml.ShowDialog() == DialogResult.OK)
                {
                    System.IO.File.WriteAllText(savemetaxml.FileName.ToString(), GenerateMetaXML());
                }
            }
        }

        public string GenerateMetaXML()
        { 
            //char quote = '"';
            string xmlgenerated = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>\r\n\t<app version=\"";
            xmlgenerated += appversion.Text + "\">\r\n\t\t";
            xmlgenerated += "<name>" + appname.Text + "</name>\r\n\t\t";
            xmlgenerated += "<coder>" + coder.Text + "</coder>\r\n\t\t";
            xmlgenerated += "<version>" + version.Text + "</version>\r\n\t\t";
            xmlgenerated += "<release_date>" + releasedate.Text + "</release_date>\r\n\t\t";
            xmlgenerated += "<short_description>" + shdesc.Text + "</short_description>\r\n\t\t";
            xmlgenerated += "<long_description>" + lngdesc.Text + "</long_description>\r\n\t</app>";
            Console.WriteLine(xmlgenerated);
            return xmlgenerated;
        }

        private void button4_Click(object sender, EventArgs e)
        {
            if (xmlfilebox.Text != "" & CheckEverything() == true)
            {
                if (MessageBox.Show("Are you sure?", "Confirm?", MessageBoxButtons.YesNo) == DialogResult.Yes)
                {
                    System.IO.File.WriteAllText(xmlfilebox.Text, GenerateMetaXML());
                }
            }
        }

        public bool CheckEverything()
        {
            bool result = true;
            //if (xmlfilebox.Text == null) result = false; not for all...
            if (appversion.Text == "") result = false;
            if (appname.Text == "") result = false;
            if (coder.Text == "") result = false;
            if (version.Text == "") result = false;
            if (releasedate.Text == "") result = false;
            if (shdesc.Text == "") result = false;
            if (lngdesc.Text == "") result = false;
            return result;
        }
    }
}
